@@ -20,6 +20,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 */
 // Self
 #include "cmsprofile.h"
+#include <config-gwenview.h>
 
 // Local
 #include <cms/cmsprofile_png.h>
@@ -42,11 +43,11 @@ extern "C" {
 #include <lcms2.h>
 
 // X11
-#ifdef Q_WS_X11
+#ifdef HAVE_X11
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <fixx11h.h>
-#include <QX11Info>
+#include <QtX11Extras/QX11Info>
 #endif
 
 namespace Gwenview
@@ -210,7 +211,7 @@ Profile::Ptr Profile::getMonitorProfile()
     cmsHPROFILE hProfile = 0;
     // Get the profile from you config file if the user has set it.
     // if the user allows override through the atom, do this:
-#ifdef Q_WS_X11
+#ifdef HAVE_X11
 
     // get the current screen...
     int screen = -1;
@@ -224,18 +225,18 @@ Profile::Ptr Profile::getMonitorProfile()
     static Atom icc_atom = XInternAtom(QX11Info::display(), "_ICC_PROFILE", True);
 
     if (XGetWindowProperty(QX11Info::display(),
-                            QX11Info::appRootWindow(screen),
-                            icc_atom,
-                            0,
-                            INT_MAX,
-                            False,
-                            XA_CARDINAL,
-                            &type,
-                            &format,
-                            &nitems,
-                            &bytes_after,
-                            (unsigned char **) &str) == Success
-    ) {
+                           QX11Info::appRootWindow(screen),
+                           icc_atom,
+                           0,
+                           INT_MAX,
+                           False,
+                           XA_CARDINAL,
+                           &type,
+                           &format,
+                           &nitems,
+                           &bytes_after,
+                           (unsigned char **) &str) == Success
+            ) {
         hProfile = cmsOpenProfileFromMem((void*)str, nitems);
     }
 #endif
