@@ -18,10 +18,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 // Self
-#include "slidecontainer.moc"
+#include "slidecontainer.h"
 
 // KDE
-#include <KDebug>
 
 // Qt
 #include <QEvent>
@@ -68,7 +67,7 @@ void SlideContainer::animTo(int newHeight)
     anim->setStartValue(slideHeight());
     anim->setEndValue(newHeight);
     anim->start(QAbstractAnimation::DeleteWhenStopped);
-    connect(anim, SIGNAL(finished()), SLOT(slotAnimFinished()));
+    connect(anim, &QPropertyAnimation::finished, this, &SlideContainer::slotAnimFinished);
     mAnim = anim;
 }
 
