@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 // Self
-#include <sorteddirmodeltest.moc>
+#include "sorteddirmodeltest.h"
 
 // Local
 #include <testutils.h>
@@ -28,13 +28,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // Qt
 
 // KDE
-#include <qtest_kde.h>
+#include <qtest.h>
 #include <KDirLister>
 #include <KTempDir>
 
 using namespace Gwenview;
 
-QTEST_KDEMAIN(SortedDirModelTest, GUI)
+QTEST_MAIN(SortedDirModelTest)
 
 void SortedDirModelTest::initTestCase()
 {
@@ -66,7 +66,7 @@ void SortedDirModelTest::testHasDocuments()
 {
     QFETCH(QString, dir);
     QFETCH(bool, hasDocuments);
-    KUrl url = KUrl::fromPath(dir);
+    QUrl url = QUrl::fromLocalFile(dir);
 
     SortedDirModel model;
     QEventLoop loop;
